pub enum PolygonRing<PointType> {
Outer(Vec<PointType>),
Inner(Vec<PointType>),
}Expand description
Rings composing a Polygon
Inner rings define holes in polygons.
In shapefile, the point ordering is what is used to know if a ring is an outer or inner one:
- Outer ring => points in clockwise order
- Inner ring => points in counter-clockwise order
Note
Rings you get access from a GenericPolygon will always have its points ordered
according to its type (outer, inner).
But PolygonRings you create won’t be reordered until you move them into
a GenericPolygon.
Example
use shapefile::{PolygonRing, Polygon, Point};
// Here the points are not in the correct order to be an Outer ring for a shapefile
let mut points = vec![
Point::new(-12.0, 6.0),
Point::new(-12.0, -6.0),
Point::new(12.0, -6.0),
Point::new(12.0, 6.0),
Point::new(-12.0, 6.0),
];
let mut reversed_points = points.clone();
reversed_points.reverse();
let ring = PolygonRing::Outer(points);
assert_ne!(ring.points(), reversed_points.as_slice());
assert_eq!(ring[0], Point::new(-12.0, 6.0));
// Now the points will be reversed
let polygon = Polygon::new(ring);
assert_eq!(polygon.rings()[0].points(), reversed_points.as_slice());Variants
Outer(Vec<PointType>)
The outer ring of a polygon.
Inner(Vec<PointType>)
Defines a hole in a polygon
Implementations
Sourceimpl<PointType> PolygonRing<PointType>
impl<PointType> PolygonRing<PointType>
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Returns the number of points inside the ring
Example
use shapefile::{PolygonRing, Point};
let ring = PolygonRing::Inner(vec![
Point::new(-12.0, 6.0),
Point::new(-12.0, -6.0),
Point::new(12.0, -6.0),
Point::new(12.0, 6.0),
Point::new(-12.0, 6.0),
]);
assert_eq!(ring.len(), 5);Sourcepub fn points(&self) -> &[PointType]
pub fn points(&self) -> &[PointType]
Returns a non-mutable slice to the points inside the ring
use shapefile::{PolygonRing, Point};
let ring = PolygonRing::Inner(vec![
Point::new(-12.0, 6.0),
Point::new(-12.0, -6.0),
Point::new(12.0, -6.0),
Point::new(12.0, 6.0),
Point::new(-12.0, 6.0),
]);
assert_eq!(ring.points()[2], Point::new(12.0, -6.0));Sourcepub fn into_inner(self) -> Vec<PointType>
pub fn into_inner(self) -> Vec<PointType>
Consumes the ring and returns its points