GenericPolyline

Struct GenericPolyline 

pub struct GenericPolyline<PointType> { /* private fields */ }
Generic struct to create Polyline; PolylineM, PolylineZ

Polylines can have multiple parts.

Polylines parts must have 2 at least 2 points

To create a polyline with only one part use new, to create a polyline with multiple parts use with_parts

geo-types

shapefile’s Polyline can be converted to geo_types’s MultiLineString<f64>

geo-types’s Line, LineString, MultiLineString can be converted to shapefile’s Polyline

let mut polylines = shapefile::read_shapes_as::<_, shapefile::Polyline>("tests/data/line.shp")?;
let geo_polyline: geo_types::MultiLineString<f64> = polylines.pop().unwrap().into();
let polyline = shapefile::Polyline::from(geo_polyline);

Implementations

Source

impl<PointType: ShrinkablePoint + GrowablePoint + Copy> GenericPolyline<PointType>

Creating a Polyline

pub fn new(points: Vec<PointType>) -> Self

Examples

Polyline with single part

use shapefile::{Point, Polyline};
let points = vec![
    Point::new(1.0, 1.0),
    Point::new(2.0, 2.0),
];
let poly = Polyline::new(points);
panic

This will panic if the vec has less than 2 points

pub fn with_parts(parts: Vec<Vec<PointType>>) -> Self

Examples

Polyline with multiple parts

use shapefile::{Point, Polyline};
let first_part = vec![
    Point::new(1.0, 1.0),
    Point::new(2.0, 2.0),
];

let second_part = vec![
    Point::new(3.0, 1.0),
    Point::new(5.0, 6.0),
];

let third_part = vec![
    Point::new(17.0, 15.0),
    Point::new(18.0, 19.0),
    Point::new(20.0, 19.0),
];
let poly = Polyline::with_parts(vec![first_part, second_part, third_part]);
panic

This will panic if any of the parts are less than 2 points

Source

impl<PointType> GenericPolyline<PointType>

pub fn bbox(&self) -> &GenericBBox<PointType>

Returns the bounding box associated to the polyline

pub fn parts(&self) -> &Vec<Vec<PointType>>

Returns a reference to all the parts

pub fn part(&self, index: usize) -> Option<&Vec<PointType>>

Returns a reference to a part

pub fn into_inner(self) -> Vec<Vec<PointType>>

Consumes the polyline and returns the parts

pub fn total_point_count(&self) -> usize

Returns the number of points contained in all the parts